@@ -1,6 +1,6 @@
 package Map::Tube::London;
 
-$Map::Tube::London::VERSION   = '0.51';
+$Map::Tube::London::VERSION   = '0.52';
 $Map::Tube::London::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ Map::Tube::London - Interface to the London Tube Map.
 
 =head1 VERSION
 
-Version 0.51
+Version 0.52
 
 =cut
 
@@ -33,6 +33,7 @@ sub _skip {
         },
         'Bakerloo' => {
             'Edgware Road'  => { 'Baker Street'  => 1 },
+            'Finchley Road' => { 'Baker Street'  => 1 },
         },
         'Circle'   => {
             'Wood Lane'     => { 'White City'    => 1 },
@@ -117,11 +118,25 @@ to be installed.
     use Map::Tube::London;
 
     my $tube = Map::Tube::London->new;
-    my $line = 'Jubilee';
+    my $line = 'Central';
     open(my $IMAGE, ">$line.png");
     print $IMAGE decode_base64($tube->as_image($line));
     close($IMAGE);
 
+The L<Central Line|https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Central.png>
+map as generated by plugin L<Map::Tube::Plugin::Graph>.
+
+=begin html
+
+<a href = "https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Central.png">
+<img src    = "https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Central.png"
+     alt    = "London Tube Map: Central Line"
+     width  = "500px"
+     height = "500px"/>
+</a>
+
+=end html
+
 =head1 AUTHOR
 
 Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
